==> apache-qpid-jms-0.1.0-src.tar.gz: apache-qpid-jms-0.1.0-src/qpid-jms-client/src/main/java/org/apache/qpid/jms/JmsQueueSender.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.qpid.jms;

import javax.jms.IllegalStateException;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.Queue;
import javax.jms.QueueSender;

import org.apache.qpid.jms.meta.JmsProducerId;

/**
 * Implementation of a Queue Sender
 */
public class JmsQueueSender extends JmsMessageProducer implements QueueSender {

    /**
     * Constructor
     *
     * @param id
     * @param session
     * @param destination
     */
    protected JmsQueueSender(JmsProducerId id, JmsSession session, JmsDestination destination) throws JMSException {
        super(id, session, destination);
    }

    /**
     * @return the Queue
     * @throws IllegalStateException
     * @see javax.jms.QueueSender#getQueue()
     */
    @Override
    public Queue getQueue() throws IllegalStateException {
        checkClosed();
        return (Queue) this.producerInfo.getDestination();
    }

    /**
     * @param queue
     * @param message
     * @throws JMSException
     * @see javax.jms.QueueSender#send(javax.jms.Queue, javax.jms.Message)
     */
    @Override
    public void send(Queue queue, Message message) throws JMSException {
        super.send(queue, message);
    }

    /**
     * @param queue
     * @param message
     * @param deliveryMode
     * @param priority
     * @param timeToLive
     * @throws JMSException
     * @see javax.jms.QueueSender#send(javax.jms.Queue, javax.jms.Message, int, int, long)
     */
    @Override
    public void send(Queue queue, Message message, int deliveryMode, int priority, long timeToLive) throws JMSException {
        super.send(message, deliveryMode, priority, timeToLive);
    }
}

==> apache-qpid-jms-2.10.0-src.tar.gz: apache-qpid-jms-2.10.0-src/qpid-jms-client/src/main/java/org/apache/qpid/jms/JmsQueueSender.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.qpid.jms;

import jakarta.jms.IllegalStateException;
import jakarta.jms.JMSException;
import jakarta.jms.Message;
import jakarta.jms.Queue;
import jakarta.jms.QueueSender;

import org.apache.qpid.jms.meta.JmsProducerId;

/**
 * Implementation of a Queue Sender
 */
public class JmsQueueSender extends JmsMessageProducer implements AutoCloseable, QueueSender {

    protected JmsQueueSender(JmsProducerId id, JmsSession session, JmsDestination destination) throws JMSException {
        super(id, session, destination);
    }

    /**
     * @see jakarta.jms.QueueSender#getQueue()
     */
    @Override
    public Queue getQueue() throws IllegalStateException {
        checkClosed();
        return (Queue) this.producerInfo.getDestination();
    }

    /**
     * @see jakarta.jms.QueueSender#send(jakarta.jms.Queue, jakarta.jms.Message)
     */
    @Override
    public void send(Queue queue, Message message) throws JMSException {
        super.send(queue, message);
    }

    /**
     * @see jakarta.jms.QueueSender#send(jakarta.jms.Queue, jakarta.jms.Message, int, int, long)
     */
    @Override
    public void send(Queue queue, Message message, int deliveryMode, int priority, long timeToLive) throws JMSException {
        super.send(queue, message, deliveryMode, priority, timeToLive);
    }
}
